pub struct FulfillmentShipmentItem {
    pub seller_sku: String,
    pub seller_fulfillment_order_item_id: String,
    pub quantity: i32,
    pub package_number: Option<i32>,
    pub serial_number: Option<String>,
}
FulfillmentShipmentItem : Item information for a shipment in a fulfillment order.

Fields

seller_sku: String

The seller SKU of the item.

seller_fulfillment_order_item_id: String

The fulfillment order item identifier that the seller created and submitted with a call to the createFulfillmentOrder operation.

quantity: i32

The item quantity.

package_number: Option<i32>

An identifier for the package that contains the item quantity.

serial_number: Option<String>

The serial number of the shipped item.

Implementations

Item information for a shipment in a fulfillment order.