Struct amazon_sp_fulfillment_outbound::models::fulfillment_shipment_item::FulfillmentShipmentItem
source · [−]pub struct FulfillmentShipmentItem {
pub seller_sku: String,
pub seller_fulfillment_order_item_id: String,
pub quantity: i32,
pub package_number: Option<i32>,
pub serial_number: Option<String>,
}Expand description
FulfillmentShipmentItem : Item information for a shipment in a fulfillment order.
Fields
seller_sku: StringThe seller SKU of the item.
seller_fulfillment_order_item_id: StringThe fulfillment order item identifier that the seller created and submitted with a call to the createFulfillmentOrder operation.
quantity: i32The item quantity.
package_number: Option<i32>An identifier for the package that contains the item quantity.
serial_number: Option<String>The serial number of the shipped item.
Implementations